@@ -18,7 +18,6 @@ import itertools
 import dns.rdata
 import dns.rdatatype
 import dns.rdataclass
-import six
 from oslo_config import cfg
 from oslo_concurrency import lockutils
 from oslo_log import log as logging
@@ -27,24 +26,8 @@ from designate.backend.agent_backend import base
 from designate import exceptions
 from designate import utils
 
+CFG_GROUP_NAME = 'backend:agent:denominator'
 LOG = logging.getLogger(__name__)
-CFG_GROUP = 'backend:agent:denominator'
-
-"""GROUP = backend:agent:denominator"""
-denominator_group = cfg.OptGroup(
-            name='backend:agent:denominator',
-            title='Backend options for Denominator',
-        )
-
-denominator_opts = [
-    cfg.StrOpt('name', default='fake',
-               help='Name of the affected provider'),
-    cfg.StrOpt('config_file', default='/etc/denominator.conf',
-               help='Path to Denominator configuration file')
-]
-
-cfg.CONF.register_group(denominator_group)
-cfg.CONF.register_opts(denominator_opts, group=denominator_group)
 
 
 class Denominator(object):
@@ -99,7 +82,7 @@ class Denominator(object):
             return stdout
         except utils.processutils.ProcessExecutionError as e:
             LOG.debug('Denominator call failure: %s' % e)
-            raise exceptions.Base(e)
+            raise exceptions.DesignateException(e)
 
 
 class DenominatorBackend(base.AgentBackend):
@@ -109,11 +92,8 @@ class DenominatorBackend(base.AgentBackend):
 
     def __init__(self, agent_service):
         super(DenominatorBackend, self).__init__(agent_service)
-        self.denominator = Denominator(cfg.CONF[CFG_GROUP])
-
-    @classmethod
-    def get_cfg_opts(cls):
-        return [(denominator_group, denominator_opts)]
+        self.denominator = Denominator(
+            cfg.CONF[CFG_GROUP_NAME])
 
     def start(self):
         LOG.info("Started Denominator backend")
@@ -141,7 +121,7 @@ class DenominatorBackend(base.AgentBackend):
     def create_zone(self, zone):
         LOG.debug("Creating %s", zone.origin.to_text())
         zone_name = zone.origin.to_text(omit_final_dot=True)
-        if six.PY3 and isinstance(zone_name, bytes):
+        if isinstance(zone_name, bytes):
             zone_name = zone_name.decode('utf-8')
 
         # Use SOA TTL as zone default TTL
@@ -175,7 +155,7 @@ class DenominatorBackend(base.AgentBackend):
     def update_zone(self, zone):
         LOG.debug("Updating %s", zone.origin)
         zone_name = zone.origin.to_text(omit_final_dot=True)
-        if six.PY3 and isinstance(zone_name, bytes):
+        if isinstance(zone_name, bytes):
             zone_name = zone_name.decode('utf-8')
 
         soa_record = zone.find_rrset(zone.origin, dns.rdatatype.SOA)
@@ -245,7 +225,7 @@ class DenominatorBackend(base.AgentBackend):
         for rname, ttl, rdata in zone.iterate_rdatas():
             name = rname.derelativize(origin=zone.origin)
             name = name.to_text(omit_final_dot=True)
-            if six.PY3 and isinstance(name, bytes):
+            if isinstance(name, bytes):
                 name = name.decode('utf-8')
 
             data = rdata.to_text(origin=zone.origin, relativize=False)
