@@ -23,14 +23,14 @@ The zone transfer request API now supports system scope and default roles.
 """
 
 deprecated_create_zone_transfer_request = policy.DeprecatedRule(
-    name="create_zone_transfer_request",
-    check_str=base.RULE_ADMIN_OR_OWNER,
-    deprecated_reason=DEPRECATED_REASON,
-    deprecated_since=versionutils.deprecated.WALLABY
+        name="create_zone_transfer_request",
+        check_str=base.RULE_ADMIN_OR_OWNER,
+        deprecated_reason=DEPRECATED_REASON,
+        deprecated_since=versionutils.deprecated.WALLABY
 )
 deprecated_get_zone_transfer_request = policy.DeprecatedRule(
     name="get_zone_transfer_request",
-    check_str=base.LEGACY_RULE_ZONE_TRANSFER,
+    check_str=base.RULE_ZONE_TRANSFER,
     deprecated_reason=DEPRECATED_REASON,
     deprecated_since=versionutils.deprecated.WALLABY
 )
@@ -40,6 +40,12 @@ deprecated_get_zone_transfer_request_detailed = policy.DeprecatedRule(
     deprecated_reason=DEPRECATED_REASON,
     deprecated_since=versionutils.deprecated.WALLABY
 )
+deprecated_find_zone_transfer_requests = policy.DeprecatedRule(
+    name="find_zone_transfer_requests",
+    check_str=base.RULE_ANY,
+    deprecated_reason=DEPRECATED_REASON,
+    deprecated_since=versionutils.deprecated.WALLABY
+)
 deprecated_update_zone_transfer_request = policy.DeprecatedRule(
     name="update_zone_transfer_request",
     check_str=base.RULE_ADMIN_OR_OWNER,
@@ -53,6 +59,7 @@ deprecated_delete_zone_transfer_request = policy.DeprecatedRule(
     deprecated_since=versionutils.deprecated.WALLABY
 )
 
+
 rules = [
     policy.DocumentedRuleDefault(
         name="create_zone_transfer_request",
@@ -70,15 +77,16 @@ rules = [
     policy.DocumentedRuleDefault(
         name="get_zone_transfer_request",
         check_str=base.RULE_ZONE_TRANSFER,
-        scope_types=['system', 'project'],
         description="Show a Zone Transfer Request",
         operations=[
             {
                 'path': '/v2/zones/tasks/transfer_requests/{zone_transfer_request_id}',  # noqa
                 'method': 'GET'
+            }, {
+                'path': '/v2/zones/tasks/transfer_requests/{zone_transfer_request_id}',  # noqa
+                'method': 'PATCH'
             }
-        ],
-        deprecated_rule=deprecated_get_zone_transfer_request
+        ]
     ),
     policy.RuleDefault(
         name="get_zone_transfer_request_detailed",
@@ -95,7 +103,7 @@ rules = [
                 'path': '/v2/zones/tasks/transfer_requests',
                 'method': 'GET'
             }
-        ],
+        ]
     ),
     policy.RuleDefault(
         name="find_zone_transfer_request",
