@@ -13,7 +13,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import six
 from oslo_config import cfg
 from oslo_log import log as logging
 
@@ -71,10 +70,9 @@ class StorageQuota(base.Quota):
 
             self.storage.update_quota(context, quota)
 
-        if resource not in list(six.iterkeys(
-               self.get_default_quotas(context))):
+        if resource not in list(self.get_default_quotas(context).keys()):
             raise exceptions.QuotaResourceUnknown("%s is not a valid quota "
-                                                  "resource" % resource)
+                                                  "resource", resource)
 
         try:
             create_quota()
