@@ -11,7 +11,7 @@
 # under the License.
 from oslo_log import log as logging
 
-import mock
+from unittest import mock
 from designate.tests.test_manage import DesignateManageTestCase
 from designate.manage.pool import PoolCommands
 from designate.tests import fixtures
